#!/srv/epages/eproot/Perl/bin/perl

use strict;
use Getopt::Long;

use DE_EPAGES::Object::API::XMLStructureImportHandler;
use DE_EPAGES::Core::API::Script qw( RunScript );

sub readCartridgesXml {
    my ($XmlFile) = @_;
    my ($hCartridgesXml, $hBaseType);

    my $ImportHandler = DE_EPAGES::Object::API::XMLStructureImportHandler->new();
    my $XMLStruct = $ImportHandler->getXMLStructure(
        $XmlFile, {'XML-Type' => 'epages_cartridges_xml'});

    #---------------------------------------------------------------------------
    # loop over <DatabaseType/>
    #---------------------------------------------------------------------------
    foreach my $RootElement (@{$XMLStruct->getRootElements()}){
        my $DatabaseType = $XMLStruct->getIDValue($RootElement,'Name');
        my $Attributes = $XMLStruct->getXMLStructAttribute($RootElement, 'Attributes');
        $hBaseType->{$DatabaseType} = $Attributes->{Base};
        #-----------------------------------------------------------------------
        # loop over <Cartridge/> with parent <DatabaseType/>
        #-----------------------------------------------------------------------
        foreach my $ChildElement (@{$XMLStruct->getChildElements($RootElement)}){
            my $Cartridge = $XMLStruct->getIDValue($ChildElement,'Package');
            my $Position = $XMLStruct->getXMLStructAttribute($ChildElement, 'Position');
            $hCartridgesXml->{$DatabaseType}->{$Cartridge} = $Position;
        }
    }
    return ($hCartridgesXml, $hBaseType);
}

sub printCartridgesXml {
    my ($hCartridgesXml, $hBaseType) = @_;

    foreach my $StoreType (sort keys %$hBaseType) {
        next unless defined $hCartridgesXml->{$StoreType};
        print $StoreType;
        print " $_" foreach sort keys %{$hCartridgesXml->{$StoreType}};
        my $BaseType = $hBaseType->{$StoreType};
        while (defined $BaseType) {
            print " $_" foreach sort keys %{$hCartridgesXml->{$BaseType}};
            $BaseType = $hBaseType->{$BaseType};
        }
        print "\n";
    }
}

sub Main {

    local $| = 1;
    my %Options = ();
    my @GetOpt = qw(help xmlfile=s);

    usage() unless GetOptions(\%Options, @GetOpt);
    usage() if $Options{help};

    $Options{xmlfile} //= "$ENV{EPAGES_CARTRIDGES}/Cartridges.xml";
    usage("No such file: $Options{xmlfile}") unless -f $Options{xmlfile};

    my ($hCartridgesXml, $hBaseType) = readCartridgesXml($Options{xmlfile});
    printCartridgesXml($hCartridgesXml, $hBaseType);
}

sub usage {
    my ($ErrorMsg) = @_;
    print STDERR "Error:\n    $ErrorMsg\n" if $ErrorMsg;
    print STDERR <<END_USAGE;
Description:
    Prints lines of space-sep. fields: first storename, then its cartridges

Usage:
    perl $0 [-xmlfile Cartridges.xml]

Options:
    -xmlfile  Cartridges.xml to read (default: $ENV{EPAGES_CARTRIDGES}/Cartridges.xml)

Flags:
    -help     show the command line options

Example:
    perl $0
END_USAGE
    exit 2;
}

RunScript(
    'Sub' => \&Main
);

1;
