#!/bin/bash

PKG=${0##*/} ; PKG=${PKG%.sh} ; PKG=${PKG/spec/epages}

#==============================================================================
# epages-ascsrv.spec
#==============================================================================

export TERM=

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/fun-epages.sh
export update_epages_environment epages_service
export etc_default enable_ipv6

. $(dirname $0)/fun-wi.sh
export set_wi set_wi_xml

. $(dirname $0)/fun-pkg.sh
export pkg_instance touch_pkg_result grep_server

. $(dirname $0)/fun-mysql.sh
export set_mysql_connection get_mysql_connection

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

# INSTANCE is always:
# last:   0 - remove last version of package
# first:  1 - install the first time
# update: 2 (or higher) - update (depending on the number of versions installed)

#..............................................................................
# epages-ascsrv-pre
#..............................................................................
epages-ascsrv-pre() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-ascsrv-pre INSTANCE RPM_VERSION'
    echo 'description: pre-installation tasks of epages-ascsrv package'
    echo 'example: epages-ascsrv-pre 0 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  local SKIP_RESTART=$(grep_server ascsrv "$EPAGES_SPEC_SKIP_RESTART" "$EPAGES_SKIP_SPEC")

  [[ -n $SKIP_RESTART ]] || epages_service stop ASC

  return $(touch_pkg_result $PKG pre 0 "SKIP_RESTART=$SKIP_RESTART")
}

#..............................................................................
# epages-ascsrv-post
#..............................................................................
epages-ascsrv-post() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-ascsrv-post INSTANCE RPM_VERSION'
    echo 'description: post-installation tasks of epages-ascsrv package'
    echo 'example: epages-ascsrv-post 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  local SKIP_RESTART=$(grep_server ascsrv "$EPAGES_SPEC_SKIP_RESTART" "$EPAGES_SKIP_SPEC")
  local KEEP_CONFIG=$(grep_server ascsrv "$EPAGES_SPEC_KEEP_CONFIG" "$EPAGES_SKIP_SPEC")
  local KEEP_SHARED_CONFIG=$(grep_server ascsrv "$EPAGES_SPEC_KEEP_SHARED_CONFIG" "$KEEP_CONFIG")

  [[ -n $KEEP_CONFIG ]] || update_epages_environment -i "$1"

  local ETC_DEFAULT=$(readlink -f $(etc_default))
  local LS_ERROR=$(ls -l $ETC_DEFAULT 2>&1 >/dev/null)
  [[ -n $LS_ERROR ]] && return $(touch_pkg_result $PKG post 1 "$LS_ERROR")
  . $ETC_DEFAULT

  local DB_CONF="$EPAGES_CONFIG/Database.d/ASPoolDB.conf"
  if [[ -f  $DB_CONF.sample.initial ]] ; then
    cp -p $DB_CONF.sample.initial $DB_CONF.initial
  fi

  if [[ -z $KEEP_SHARED_CONFIG ]] ; then
    [[  -f $DB_CONF ]] || cp -p $DB_CONF.initial $DB_CONF
    set_wi EXCEPTION_HOST
    [[ $INSTANCE = first ]] && set_wi_xml ASC
  fi
  [[ -n $KEEP_CONFIG ]] && enable_ipv6

  [[ -z $SKIP_RESTART ]] && epages_service restart ASC

  return $(touch_pkg_result $PKG post 0 "SKIP_RESTART=$SKIP_RESTART KEEP_CONFIG=$KEEP_CONFIG")
}

#..............................................................................
# epages-ascsrv-preun
#..............................................................................
epages-ascsrv-preun() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-ascsrv-preun INSTANCE RPM_VERSION'
    echo 'description: preun-uninstallation tasks of epages-ascsrv package'
    echo 'example: epages-ascsrv-preun 0 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  return $(touch_pkg_result $PKG preun 0)
}

#------------------------------------------------------------------------------
# execute
# -----------------------------------------------------------------------------

case $1 in
  pre)   epages-ascsrv-pre   $2 $3 ; exit $? ;;
  post)  epages-ascsrv-post  $2 $3 ; exit $? ;;
  preun) epages-ascsrv-preun $2 $3 ; exit $? ;;
  *) exit 1 ;;
esac

#------------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
