#!/bin/bash

PKG=${0##*/} ; PKG=${PKG%.sh} ; PKG=${PKG/spec/epages}

#==============================================================================
# epages-j.spec
#==============================================================================

export TERM=

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/fun-account.sh
export add_user chown_epages

. $(dirname $0)/fun-epages.sh
export create_etc_default update_epages_environment link_epages link_etc

. $(dirname $0)/fun-j.sh
export install_epagesj_conf start_epagesj epagesj_drop_cores
export update_epagesj_conf update_epagesj_conf_dir create_ep6WebService_conf

. $(dirname $0)/fun-java.sh
export start_mongodb test_version

. $(dirname $0)/fun-pkg.sh
export pkg_instance pkg_installed touch_pkg_result mktempdir grep_server

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

# INSTANCE is always:
# last:   0 - remove last version of package
# first:  1 - install the first time
# update: 2 (or higher) - update (depending on the number of versions installed)

#..............................................................................
# epages-j-pre
#..............................................................................
epages-j-pre() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-j-pre INSTANCE RPM_VERSION'
    echo 'description: pre-uninstallation tasks of epages-j package'
    echo 'example: epages-j-pre 0 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  if [[ $INSTANCE = first ]] ; then
    add_user -u AS -g AS -G WS
    add_user -u J -g AS -G WS
  fi

  local SKIP_RESTART=$(grep_server j "$EPAGES_SPEC_SKIP_RESTART" "$EPAGES_SKIP_SPEC")

  for i in epages-solr epages-solr-slave epagesj ; do
    [[ -n $SKIP_RESTART ]] && continue
    /etc/init.d/$i status >/dev/null 2>&1 && /etc/init.d/$i stop
  done

  local EPAGESJ="${RPM_INSTALL_PREFIX:-/srv/epages}"/eproot/j
  local VERSION_FILE=$(mktempdir $PKG)/prev.version

  rm -rf "$EPAGESJ"/work/* $VERSION_FILE

  if cd "$EPAGESJ" 2>/dev/null ; then
    rm -rf rpmsave ; mkdir -m 755 -p rpmsave
    tar cf - */conf 2>/dev/null | ( cd rpmsave ; tar xf - )
    cp -rp "$EPAGESJ"/conf rpmsave/conf 2>/dev/null
  fi

  # remember previous epages-j version
  pkg_installed -V j | tail -1 | sed 's,-.*,,' > $VERSION_FILE

  epagesj_drop_cores -b $VERSION && DROP_CORES=1 || DROP_CORES=
  if [[ $INSTANCE != first && -n $DROP_CORES ]] ; then
    echo "rm -rf $EPAGESJ/cores/*"
    rm -rf "$EPAGESJ"/cores/*
  else
    DROP_CORES=
  fi

  return $(touch_pkg_result $PKG pre 0 "SKIP_RESTART=$SKIP_RESTART DROP_CORES=$DROP_CORES")
}

#..............................................................................
# epages-j-post
#..............................................................................
epages-j-post() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-j-post INSTANCE RPM_VERSION'
    echo 'description: post-installation tasks of epages-j package'
    echo 'example: epages-j-post 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  create_etc_default epagesj.ept

  # legacy, SKIP_START_JAVA is deprecated
  SKIP_START_JAVA=${SKIP_START_JAVA:-$EPAGES_SKIP_SPEC}

  local SKIP_RESTART=$(grep_server j "$EPAGES_SPEC_SKIP_RESTART" "$SKIP_START_JAVA")
  local KEEP_CONFIG=$(grep_server j "$EPAGES_SPEC_KEEP_CONFIG" "$EPAGES_SKIP_SPEC")

  [[ -n $KEEP_CONFIG ]] || update_epages_environment -i "$1"

  link_epages $RPM_INSTALL_PREFIX

  link_etc default

  [[ $INSTANCE = first && -z $KEEP_CONFIG ]] && enable_ipv6

  local ETC_DEFAULT=$(readlink -f $(etc_default))
  local LS_ERROR=$(ls -l $ETC_DEFAULT 2>&1 >/dev/null)
  [[ -n $LS_ERROR ]] && return $(touch_pkg_result $PKG post 1 "$LS_ERROR")
  . $ETC_DEFAULT

  local EPAGESJ="${RPM_INSTALL_PREFIX:-/srv/epages}"/eproot/j

  if [[ -z $KEEP_CONFIG ]] ; then
    # update epagesj.confEPAGESJ_CONFIG="$EPAGESJ"/conf
    EPAGESJ_CONFIG=${EPAGESJ_CONFIG:-"$EPAGESJ"/conf}
    local CONF="$EPAGESJ_CONFIG"/epagesj.conf
    local SAMPLE="$EPAGESJ_CONFIG"/epagesj.sample.conf

    [[ -f "$SAMPLE" ]] && /bin/cp -p "$SAMPLE" "$CONF"
    [[ $INSTANCE = first ]] && install_epagesj_conf || update_epagesj_conf
  fi

  # update all other configuration files
  [[ $INSTANCE = first ]] || update_epagesj_conf_dir "$KEEP_CONFIG"

  # create ep6WebService.conf
  if [[ ! -f "$EPAGESJ_CONFIG"/ep6WebService.conf ]] ; then
    create_ep6WebService_conf
  fi

  [[ -z $KEEP_CONFIG ]] && chown_epages -R J "$EPAGESJ"

  local PREV_VERSION=0
  local VERSION_FILE=$(mktempdir $PKG)/prev.version
  [[ -f $VERSION_FILE ]] && PREV_VERSION=$(cat $VERSION_FILE)
  PREV_VERSION=${PREV_VERSION//[^0-9.]/}
  PREV_VERSION=${PREV_VERSION:-0}

  if [[ -z $SKIP_RESTART ]] ; then
    local ConfigureEpagesJ="$EPAGES_CARTRIDGES"/DE_EPAGES/Flex/bin/customize/ConfigureEpagesJ.sh
    if [[ -f $ConfigureEpagesJ ]] ; then
      # set corePoolSize=1 in epagesj.conf if there is a flex store
      grep -q 'DE_EPAGES::Flex=' "$EPAGES_CONFIG"/Cartridges.d/*.conf 2>/dev/null \
      && bash "$ConfigureEpagesJ" -norestart 2>/dev/null
    fi

    start_mongodb
    local START_SERVICE=
    # if version to install >= 6.17.14 and initial installation or previous version < 6.17.14
    if test_version $VERSION -ge 6.17.14 && test_version $PREV_VERSION -lt 6.17.14 ; then
      # stop service epagesj if it can't connect to epagesj mysqldb
      if ! /var/epages/CheckMySQLConnection.sh epagesj >/dev/null 2>&1 ; then
        START_SERVICE="epages-solr epages-solr-slave"
        echo "-> service epagesj was stopped: no connection to epagesj MySQL database"
        echo "-> epagesj will be started after epages $VERSION is installed"
      fi
    fi
    start_epagesj $START_SERVICE
  fi

  return $(touch_pkg_result $PKG post 0 "SKIP_RESTART=$SKIP_RESTART KEEP_CONFIG=$KEEP_CONFIG")
}

#------------------------------------------------------------------------------
# execute
# -----------------------------------------------------------------------------

case $1 in
  pre)   epages-j-pre $2 $3 ; exit $? ;;
  post)  epages-j-post $2 $3 ; exit $? ;;
  *) exit 1 ;;
esac

#------------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
