#!/bin/bash

PKG=${0##*/} ; PKG=${PKG%.sh} ; PKG=${PKG/spec/epages}

#==============================================================================
# epages-mysql.spec
#==============================================================================

export TERM=

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/fun-account.sh
export add_user get_user_info get_group_info

. $(dirname $0)/fun-pkg.sh
export pkg_instance touch_pkg_result

. $(dirname $0)/fun-mysql.sh
export check_mysqld_rpm create_mysql_directories add_innodb_data_file_path

. $(dirname $0)/fun-java.sh
export test_version

. $(dirname $0)/fun-arch.sh
export EPAGES_KERNEL

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

# INSTANCE is always:
# last:   0 - remove last version of package
# first:  1 - install the first time
# update: 2 (or higher) - update (depending on the number of versions installed)

#..............................................................................
# epages-mysql-pre
#..............................................................................
epages-mysql-pre() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-mysql-pre INSTANCE RPM_VERSION'
    echo 'description: pre-installation tasks of epages-mysql package'
    echo 'example: epages-mysql-pre 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  if [[ $EPAGES_KERNEL != ${EPAGES_KERNEL%d} ]] ; then
    return $(touch_pkg_result $PKG pre 0 "debian: skip")
  fi

  add_user -u MYSQL -g MYSQL
  create_mysql_directories

  if check_mysqld_rpm 5.6 epages-mysqld >/dev/null ; then
    return $(touch_pkg_result $PKG pre 0 "check_mysqld_rpm 5.6 epages-mysqld -> 0")
  fi

  # innodb_data_file_path must be set if installed MySQL version < 5.5
  # see http://sharadchhetri.com/2014/11/29/upgrading-mysql-5-1-5-6-service-failed-start/
  local INSTALLED_MYSQL_VERSION=$(check_mysqld_rpm 5.6 2>/dev/null)
  if [[ -n $INSTALLED_MYSQL_VERSION ]] ; then
    if test_version $INSTALLED_MYSQL_VERSION -ge 5.5 ; then
      return $(touch_pkg_result $PKG pre 1 "test_version $INSTALLED_MYSQL_VERSION -ge 5.5 -> 1")
    fi
  fi

  add_innodb_data_file_path

  return $(touch_pkg_result $PKG pre 1)
}

#..............................................................................
# epages-mysql-post
#..............................................................................
epages-mysql-post() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-mysql-post INSTANCE RPM_VERSION'
    echo 'description: post-installation tasks of epages-mysql package'
    echo 'example: epages-mysql-post 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  [[ $INSTANCE = first ]] || return $(touch_pkg_result $PKG post 0 "INSTANCE=$INSTANCE")

  add_user -u AS -G MYSQL
  add_user -u AS_RUN -G MYSQL
  add_user -u MYSQL -G AS

  return $(touch_pkg_result $PKG post 0)
}

#------------------------------------------------------------------------------
# execute
# -----------------------------------------------------------------------------

case $1 in
  pre)  epages-mysql-pre $2 $3 ; exit $? ;;
  post) epages-mysql-post $2 $3 ; exit $? ;;
  *) exit 1 ;;
esac

#------------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
