#!/bin/bash

PKG=${0##*/} ; PKG=${PKG%.sh} ; PKG=${PKG/spec/epages}

#==============================================================================
# epages-mysqld.spec
#==============================================================================

export TERM=

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/fun-account.sh
export add_user

. $(dirname $0)/fun-pkg.sh
export pkg_instance touch_pkg_result grep_server

. $(dirname $0)/fun-linux.sh
export chkconfig_do

. $(dirname $0)/fun-epages.sh
export etc_default

. $(dirname $0)/fun-mysql.sh
export check_mysqld_rpm create_mysql_directories add_innodb_data_file_path

. $(dirname $0)/fun-java.sh
export test_version

. $(dirname $0)/fun-arch.sh
export EPAGES_KERNEL

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

# INSTANCE is always:
# last:   0 - remove last version of package
# first:  1 - install the first time
# update: 2 (or higher) - update (depending on the number of versions installed)

#..............................................................................
# epages-mysqld-pre
#..............................................................................
epages-mysqld-pre() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-mysqld-pre INSTANCE RPM_VERSION'
    echo 'description: pre-installation tasks of epages-mysqld package'
    echo 'example: epages-mysqld-pre 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  if [[ $EPAGES_KERNEL != ${EPAGES_KERNEL%d} ]] ; then
    return $(touch_pkg_result $PKG pre 0 "debian: skip")
  fi

  add_user -u MYSQL -g MYSQL
  create_mysql_directories

  if check_mysqld_rpm 5.6 epages-mysqld >/dev/null ; then
    return $(touch_pkg_result $PKG pre 0 "check_mysqld_rpm 5.6 epages-mysqld -> 0")
  fi

  # innodb_data_file_path must be set if installed MySQL version < 5.5
  # see http://sharadchhetri.com/2014/11/29/upgrading-mysql-5-1-5-6-service-failed-start/
  local INSTALLED_MYSQL_VERSION=$(check_mysqld_rpm 5.6 2>/dev/null)
  if [[ -n $INSTALLED_MYSQL_VERSION ]] ; then
    if test_version $INSTALLED_MYSQL_VERSION -ge 5.5 ; then
      return $(touch_pkg_result $PKG pre 1 "test_version $INSTALLED_MYSQL_VERSION -ge 5.5 -> 1")
    fi
  fi

  add_innodb_data_file_path

  return $(touch_pkg_result $PKG pre 1)
}

#..............................................................................
# epages-mysqld-post
#..............................................................................
epages-mysqld-post() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-mysqld-post INSTANCE RPM_VERSION'
    echo 'description: post-installation tasks of epages-mysqld package'
    echo 'example: epages-mysqld-post 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  local SKIP_RESTART=$(grep_server mysqld "$EPAGES_SPEC_SKIP_RESTART" "$EPAGES_SKIP_SPEC")
  local KEEP_CONFIG=$(grep_server mysqld "$EPAGES_SPEC_KEEP_CONFIG" "$EPAGES_SKIP_SPEC")

  [[ $INSTANCE = first ]] || return $(touch_pkg_result $PKG post 0 "INSTANCE=$INSTANCE")

  local ETC_DEFAULT=$(etc_default ${RPM_INSTALL_PREFIX:-/srv/epages})
  [[ -f $(readlink -f "$ETC_DEFAULT") ]] && . "$ETC_DEFAULT"

  local EPAGES_MYSQLD=$(mysqld_name)
  [[ -z $EPAGES_MYSQLD ]] && return $(touch_pkg_result $PKG post 0 "EPAGES_MYSQLD=")

  [[ -n $KEEP_CONFIG ]] || enable_ipv6

  chkconfig_do --del $EPAGES_MYSQLD
  local RUN_SCRIPT=/etc/init.d/$EPAGES_MYSQLD
  if [[ -e $RUN_SCRIPT ]] ; then
    if ! grep -q 'chkconfig: 235' $RUN_SCRIPT ; then
      sed -i 's/\(chkconfig:\) -/\1 235/' $(readlink -qf $RUN_SCRIPT)
    fi
    chmod 755 $RUN_SCRIPT
  fi
  chkconfig_do --add $EPAGES_MYSQLD

  [[ -n $SKIP_RESTART ]] || service $EPAGES_MYSQLD start

  if [[ -n $KEEP_CONFIG ]] ; then
    return $(touch_pkg_result $PKG post 0 "KEEP_CONFIG=$KEEP_CONFIG")
  fi

  create_mysql_directories

  local RESULT=0
  trap '' TERM
  /var/epages/bin/SetupMySQL.sh || RESULT=$?

  return $(touch_pkg_result $PKG post $RESULT "/var/epages/bin/SetupMySQL.sh -> $RESULT")
}

#------------------------------------------------------------------------------
# execute
# -----------------------------------------------------------------------------

case $1 in
  pre)  epages-mysqld-pre $2 $3 ; exit $? ;;
  post) epages-mysqld-post $2 $3 ; exit $? ;;
  *) exit 1 ;;
esac

#------------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
