#!/bin/bash

PKG=${0##*/} ; PKG=${PKG%.sh} ; PKG=${PKG/spec/epages}

#==============================================================================
# epages-patch.spec
#==============================================================================

export TERM=

#------------------------------------------------------------------------------
# recognized variables
#------------------------------------------------------------------------------

export EPAGES_DO_PATCH

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/fun-pkg.sh
export pkg_instance required_pkg_version show_failed_dependency touch_pkg_result grep_server

. $(dirname $0)/fun-patch.sh
export check_prerequistes patch_epages patch_repo cleanup_patch

. $(dirname $0)/fun-perl.sh
export new_perl_binaries

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

# INSTANCE is always:
# last:   0 - remove last version of package
# first:  1 - install the first time
# update: 2 (or higher) - update (depending on the number of versions installed)

#..............................................................................
# epages-patch-pre
#..............................................................................
epages-patch-pre() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-patch-pre INSTANCE RPM_VERSION'
    echo 'description: pre-uninstallation tasks of epages-patch package'
    echo 'example: epages-patch-pre 0 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  [[ $INSTANCE = update ]] || return $(touch_pkg_result $PKG pre 0 "INSTANCE=$INSTANCE")

  local SKIP_RESTART=$(grep_server patch "$EPAGES_SPEC_SKIP_RESTART" "$EPAGES_SKIP_SPEC")

  local REQ_VERSION=$(new_perl_binaries $VERSION)
  if [[ -z $SKIP_RESTART && -n $REQ_VERSION ]] ; then
    show_failed_dependency epages-patch-$VERSION epages-perl-$REQ_VERSION \
    "ENABLE_REPO=epages-setup /var/epages/install-RPM.sh epages-perl"
    return $(touch_pkg_result $PKG pre 1 "new_perl_binaries $VERSION -> required: $REQ_VERSION")
  fi

  if [[ -n $SKIP_RESTART ]] ; then
    return $(touch_pkg_result $PKG pre 0 "SKIP_RESTART=$SKIP_RESTART")
  fi

  if ! check_prerequistes $VERSION ; then
    return $(touch_pkg_result $PKG pre 1 "check_prerequistes $VERSION -> FAILURE")
  fi

  cleanup_patch $VERSION
  return $(touch_pkg_result $PKG pre 0 "SKIP_RESTART=$SKIP_RESTART")
}

#..............................................................................
# epages-patch-post
#..............................................................................
epages-patch-post() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-patch-post INSTANCE RPM_VERSION'
    echo 'description: post-installation tasks of epages-patch package'
    echo 'example: epages-patch-post 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  local SKIP_RESTART=$(grep_server patch "$EPAGES_SPEC_SKIP_RESTART" "$EPAGES_SKIP_SPEC")

  if [[ $INSTANCE != update ]] ; then
    return $(touch_pkg_result $PKG post 0 "INSTANCE=$INSTANCE")
  elif [[ -n $SKIP_RESTART ]] ; then
    return $(touch_pkg_result $PKG post 0 "SKIP_RESTART=$SKIP_RESTART")
  fi

  patch_epages $VERSION
  return $(touch_pkg_result $PKG post $? "patch_epages $VERSION -> $?")
}

#..............................................................................
# epages-patch-patched
#..............................................................................
epages-patch-patched() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-patch-patched INSTANCE RPM_VERSION'
    echo 'description: epages-patch tasks after successful post-installation'
    echo 'example: epages-patch-patched 0 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  local SKIP_RESTART=$(grep_server patch "$EPAGES_SPEC_SKIP_RESTART" "$EPAGES_SKIP_SPEC")

  patch_repo $VERSION
  [[ -n $SKIP_RESTART ]] || cleanup_patch $VERSION

  return $(touch_pkg_result $PKG patched 0 "SKIP_RESTART=$SKIP_RESTART")
}

#------------------------------------------------------------------------------
# execute
# -----------------------------------------------------------------------------

case $1 in
  pre)     epages-patch-pre     $2 $3 ; exit $? ;;
  post)    epages-patch-post    $2 $3 ; exit $? ;;
  patched) epages-patch-patched $2 $3 ; exit $? ;;
  *) exit 1 ;;
esac

#------------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
