#!/bin/bash

PKG=${0##*/} ; PKG=${PKG%.sh} ; PKG=${PKG/spec/epages}

#==============================================================================
# epages-reqsrv.spec
#==============================================================================

export TERM=

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/fun-epages.sh
export update_epages_environment epages_service
export etc_default enable_ipv6 set_local_ips

. $(dirname $0)/fun-wi.sh
export set_wi set_wi_xml

. $(dirname $0)/fun-pkg.sh
export pkg_instance touch_pkg_result grep_server

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

# INSTANCE is always:
# last:   0 - remove last version of package
# first:  1 - install the first time
# update: 2 (or higher) - update (depending on the number of versions installed)

#..............................................................................
# epages-reqsrv-pre
#..............................................................................
epages-reqsrv-pre() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-reqsrv-pre INSTANCE RPM_VERSION'
    echo 'description: pre-installation tasks of epages-reqsrv package'
    echo 'example: epages-reqsrv-pre 0 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  local SKIP_RESTART=$(grep_server reqsrv "$EPAGES_SPEC_SKIP_RESTART" "$EPAGES_SKIP_SPEC")

  [[ -n $SKIP_RESTART ]] || epages_service stop RR

  return $(touch_pkg_result $PKG pre 0 "SKIP_RESTART=$SKIP_RESTART")
}

#..............................................................................
# epages-reqsrv-post
#..............................................................................
epages-reqsrv-post() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-reqsrv-post INSTANCE RPM_VERSION'
    echo 'description: post-installation tasks of epages-reqsrv package'
    echo 'example: epages-reqsrv-post 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  local SKIP_RESTART=$(grep_server reqsrv "$EPAGES_SPEC_SKIP_RESTART" "$EPAGES_SKIP_SPEC")
  local KEEP_CONFIG=$(grep_server reqsrv "$EPAGES_SPEC_KEEP_CONFIG" "$EPAGES_SKIP_SPEC")
  local KEEP_SHARED_CONFIG=$(grep_server reqsrv "$EPAGES_SPEC_KEEP_SHARED_CONFIG" "$KEEP_CONFIG")

  [[ -n $KEEP_CONFIG ]] || update_epages_environment -i "$1"

  local ETC_DEFAULT=$(readlink -f $(etc_default))
  local LS_ERROR=$(ls -l $ETC_DEFAULT 2>&1 >/dev/null)
  [[ -n $LS_ERROR ]] && return $(touch_pkg_result $PKG post 1 "$LS_ERROR")
  . $ETC_DEFAULT

  local HAS_ASC=$(strings $EP_RR | grep -i cacheserver)

  if [[ -n $HAS_ASC && -z $KEEP_SHARED_CONFIG && $INSTANCE = first ]] ; then
    set_wi EXCEPTION_HOST
    set_wi_xml RR
  elif [[ -z $KEEP_SHARED_CONFIG && $INSTANCE = first ]] ; then
    set_wi RR RR2AS EXCEPTION_HOST SECTIONS
    set_local_ips RR
  fi

  [[ $INSTANCE = first && -z $KEEP_CONFIG ]] && enable_ipv6

  [[ -n $SKIP_RESTART ]] || epages_service restart RR

  return $(touch_pkg_result $PKG post 0 "SKIP_RESTART=$SKIP_RESTART KEEP_CONFIG=$KEEP_CONFIG")
}

#..............................................................................
# epages-reqsrv-preun
#..............................................................................
epages-reqsrv-preun() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-reqsrv-preun INSTANCE RPM_VERSION'
    echo 'description: preun-uninstallation tasks of epages-reqsrv package'
    echo 'example: epages-reqsrv-preun 0 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  return $(touch_pkg_result $PKG preun 0)
}

#------------------------------------------------------------------------------
# execute
# -----------------------------------------------------------------------------

case $1 in
  pre)  epages-reqsrv-pre  $2 $3 ; exit $? ;;
  post)  epages-reqsrv-post  $2 $3 ; exit $? ;;
  preun) epages-reqsrv-preun $2 $3 ; exit $? ;;
  *) exit 1 ;;
esac

#------------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
