#!/bin/bash

PKG=${0##*/} ; PKG=${PKG%.sh} ; PKG=${PKG/spec/epages}

#==============================================================================
# epages-requires.spec
#==============================================================================

export TERM=

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/fun-pkg.sh
export pkg_instance touch_pkg_result grep_server

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

# INSTANCE is always:
# last:   0 - remove last version of package
# first:  1 - install the first time
# update: 2 (or higher) - update (depending on the number of versions installed)

#..............................................................................
# epages-requires-post
#..............................................................................
epages-requires-post() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-requires-post INSTANCE RPM_VERSION'
    echo 'description: post-installation tasks of epages-requires package'
    echo 'example: epages-requires-post 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2
  local NSS_TAR=$(mktempdir $PKG)/nss_softokn.tar
  local RESULT

  local KEEP_CONFIG=$(grep_server requires "${EPAGES_SPEC_KEEP_CONFIG:+1}" "$EPAGES_SKIP_SPEC")

  if [[ -n $KEEP_CONFIG ]] ; then
    return $(touch_pkg_result $PKG post 0 "KEEP_CONFIG=$KEEP_CONFIG")
  elif [[ ! -f $NSS_TAR ]] ; then
    return $(touch_pkg_result $PKG post 0 "not found: $NSS_TAR")
  fi

  # do nothing if rpm program works
  if rpm --quiet -q epages-release 2>/dev/null ; then
    mv $NSS_TAR $NSS_TAR.~$$~
    RESULT=$?
    return $(touch_pkg_result $PKG post $RESULT "mv $NSS_TAR $NSS_TAR.~$$~ -> $RESULT")
  fi

  # if tar file to backup softokn libraries was created before
  # restore these libraries by unpacking the tar
  pushd / >/dev/null
  tar xf $NSS_TAR
  mv $NSS_TAR $NSS_TAR.~$$~
  RESULT=$?
  popd >/dev/null

  return $(touch_pkg_result $PKG post $RESULT "mv $NSS_TAR $NSS_TAR.~$$~ -> $RESULT")
}

#------------------------------------------------------------------------------
# execute
# -----------------------------------------------------------------------------

case $1 in
  post)    epages-requires-post $2 $3 ; exit $? ;;
  *) exit 1 ;;
esac

#------------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
