#!/bin/bash

PKG=${0##*/} ; PKG=${PKG%.sh} ; PKG=${PKG/spec/epages}

#==============================================================================
# epages-setup.spec
#==============================================================================

export TERM=

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/fun-epages.sh
export etc_default

. $(dirname $0)/fun-pkg.sh
export pkg_instance touch_pkg_result

. $(dirname $0)/fun-mysql.sh
export check_mysqld_rpm

. $(dirname $0)/fun-arch.sh
export EPAGES_KERNEL

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

# INSTANCE is always:
# last:   0 - remove last version of package
# first:  1 - install the first time
# update: 2 (or higher) - update (depending on the number of versions installed)

#..............................................................................
# epages-setup-pre
#..............................................................................
epages-setup-pre() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-setup-pre INSTANCE RPM_VERSION'
    echo 'description: pre-installation tasks of epages-setup package'
    echo 'example: epages-setup-pre 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  [[ $SKIP_MYSQL = 1 ]] && return $(touch_pkg_result $PKG pre 0 "SKIP_MYSQL=1")
  if [[ $EPAGES_KERNEL != ${EPAGES_KERNEL%d} ]] ; then
    return $(touch_pkg_result $PKG pre 0 "debian: skip: check_mysqld_rpm 5.6 epages-setup")
  fi

  check_mysqld_rpm 5.6 epages-setup >/dev/null
  local RESULT=$?
  return $(touch_pkg_result $PKG pre $RESULT "check_mysqld_rpm 5.6 epages-setup -> $RESULT")
}

#..............................................................................
# epages-setup-post
#..............................................................................
epages-setup-post() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-setup-post INSTANCE RPM_VERSION'
    echo 'description: post-installation tasks of epages-setup package'
    echo 'example: epages-setup-post 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  if [[ $INSTANCE != first ]] ; then
    return $(touch_pkg_result $PKG post 0 "INSTANCE=$INSTANCE")
  elif [[ -n $EPAGES_SKIP_SPEC ]] ; then
    return $(touch_pkg_result $PKG post 0 "EPAGES_SKIP_SPEC=$EPAGES_SKIP_SPEC")
  fi

  local ETC_DEFAULT=$(readlink -f $(etc_default))
  local LS_ERROR=$(ls -l $ETC_DEFAULT 2>&1 >/dev/null)
  [[ -n $LS_ERROR ]] && return $(touch_pkg_result $PKG post 1 "$LS_ERROR")

  /var/epages/SetupEpages.sh
  local RESULT=$?
  return $(touch_pkg_result $PKG post $RESULT "/var/epages/SetupEpages.sh -> $RESULT")
}

#------------------------------------------------------------------------------
# execute
# -----------------------------------------------------------------------------

case $1 in
  pre)  epages-setup-pre $2 $3 ; exit $? ;;
  post) epages-setup-post $2 $3 ; exit $? ;;
  *) exit 1 ;;
esac

#------------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
