#!/bin/bash

PKG=${0##*/} ; PKG=${PKG%.sh} ; PKG=${PKG/spec/epages}

#==============================================================================
# epages-webconf.spec
#==============================================================================

export TERM=

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

. $(dirname $0)/fun-epages.sh
export update_epages_environment set_epages_conf
export get_cartridge_version internal_version etc_default

. $(dirname $0)/fun-httpd.sh
export setup_etc_apache set_apache_envvars disable_eproot_apache 
export add_dummy_cert start_epages_apache mkdir_epages_apache
export set_selinux4httpd

. $(dirname $0)/fun-pkg.sh
export pkg_instance touch_pkg_result grep_server

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

# INSTANCE is always:
# last:   0 - remove last version of package
# first:  1 - install the first time
# update: 2 (or higher) - update (depending on the number of versions installed)

#..............................................................................
# epages-webconf-pre
#..............................................................................
epages-webconf-pre() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-webconf-pre INSTANCE RPM_VERSION'
    echo 'description: pre-installation tasks of epages-webconf package'
    echo 'example: epages-webconf-pre 0 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  return $(touch_pkg_result $PKG pre 0)
}

#..............................................................................
# epages-webconf-post
#..............................................................................
epages-webconf-post() {
  if [[ $# -ne 2 || -z $1 || -z $2 ]] ; then
    echo 'syntax: epages-webconf-post INSTANCE RPM_VERSION'
    echo 'description: post-installation tasks of epages-webconf package'
    echo 'example: epages-webconf-post 1 6.16.4'
    return 1
  fi
  local INSTANCE=$(pkg_instance $1)
  local VERSION=$2

  local SKIP_RESTART=$(grep_server webconf "$EPAGES_SPEC_SKIP_RESTART" "$EPAGES_SKIP_SPEC")
  local KEEP_CONFIG=$(grep_server webconf "$EPAGES_SPEC_KEEP_CONFIG" "$EPAGES_SKIP_SPEC")
  local KEEP_SHARED_CONFIG=$(grep_server webconf "$EPAGES_SPEC_KEEP_SHARED_CONFIG" "$KEEP_CONFIG")

  [[ -n $KEEP_CONFIG ]] || update_epages_environment -i "$1"

  local ETC_DEFAULT=$(readlink -f $(etc_default))
  local LS_ERROR=$(ls -l $ETC_DEFAULT 2>&1 >/dev/null)
  [[ -n $LS_ERROR ]] && return $(touch_pkg_result $PKG post 1 "$LS_ERROR")
  . $ETC_DEFAULT

  if [[ -z $KEEP_CONFIG ]] ; then
    rm -f "$EPAGES"/bin/dummycert.sh "$EPAGES"/bin/use-local-httpd.sh
    rm -f "$EPAGES"/bin/set-local-ips.sh "$EPAGES"/bin/update-rewrite-conf.sh
    rm -f "$EPAGES"/WebAdapter/zzz-epages-*.ept

    local INSTANCE_ORIG=$INSTANCE
    if [[ $INSTANCE != first && ! -f /etc/debian_version ]] ; then
      local CORE_VERSION=$(get_cartridge_version --from-conf Core)
      [[ -n ${CORE_VERSION//[0-9.]/} ]] && CORE_VERSION=
      local INTERNAL_VERSION=${CORE_VERSION:+$(internal_version $CORE_VERSION)}
      [[ ${INTERNAL_VERSION:-0} -lt 6017005 ]] && INSTANCE=first
    fi

    disable_eproot_apache
  fi

  if [[ $INSTANCE = first ]] ; then
    setup_etc_apache epages
    set_apache_envvars
    . /etc/apache2-epages/envvars
    add_dummy_cert $APACHE_SERVER_NAME
    if [[ -z $KEEP_CONFIG ]] ; then
      local SCRIPT=$EPAGES_CARTRIDGES/DE_EPAGES/WebInterface/Scripts/patchWebInterface.pl
      [[ $INSTANCE_ORIG != first && -f $SCRIPT ]] && $PERL $SCRIPT
    fi
  else
    . /etc/apache2-epages/envvars
  fi

  # if directory exists this is not a first installation
  [[ -d "$EPAGES_WEBROOT"/StoreTypes/ ]] && INSTANCE=

  # create /etc/apache2-epages/webservertest/test.html unless exists
  local WEBSERVERTEST=/etc/apache2-epages/webservertest/test.html
  if [[ ! -f $WEBSERVERTEST && -f $WEBSERVERTEST.initial ]] ; then
    /bin/cp -p $WEBSERVERTEST.initial $WEBSERVERTEST
  fi
  
  mkdir_epages_apache $INSTANCE
  set_selinux4httpd

  [[ -n $KEEP_SHARED_CONFIG ]] || set_epages_conf $APACHE_SERVER_NAME $APACHE_PORT

  if [[ -z $SKIP_RESTART && $INSTANCE_ORIG = first ]] ; then
    start_epages_apache
  elif [[ -z $SKIP_RESTART ]] ; then
    start_epages_apache reload
  fi

  return $(touch_pkg_result $PKG post 0 "SKIP_RESTART=$SKIP_RESTART KEEP_CONFIG=$KEEP_CONFIG")
}

#------------------------------------------------------------------------------
# execute
# -----------------------------------------------------------------------------

case $1 in
  pre)  epages-webconf-pre $2 $3 ; exit $? ;;
  post) epages-webconf-post $2 $3 ; exit $? ;;
  *) exit 1 ;;
esac

#------------------------------------------------------------------------------
# exit
# -----------------------------------------------------------------------------
