#!/bin/env bash

BN=${0##*/}
DN=$(cd $(dirname $0) && pwd)

usage() {
  ( echo "Usage:"
    echo "  $BN -s epages6 -t epages6.ept [-i]"
    echo "Options:"
    echo "  -s: file to change (e.g.: /etc/default/epages6)"
    echo "  -t: new template file (e.g.: /srv/epages/etc/default/epages6.ept)"
    echo "  -i: edit file to change in place" ) 1>&2
  exit 1
}

[[ $# -eq 0 ]] && usage

unset ETC_DEFAULT DEFAULT_EPT INPLACE
while getopts s:t:i c ; do
  case $c in
    s) ETC_DEFAULT=$OPTARG ;;
    t) DEFAULT_EPT=$OPTARG ;;
    i) INPLACE=1 ;;
    *) usage ;;
  esac
done

[[ -z $ETC_DEFAULT || -z $DEFAULT_EPT ]] && usage
ls "$DEFAULT_EPT" >/dev/null || usage

PATH=$DN:/var/epages:$PATH
for i in functions.sh ini-config.sh ; do
  type $i >/dev/null || exit $?
done

TEMP=/tmp/epages/epages-patch
mkdir -m 1777 -p /tmp/epages $TEMP
TEMP_FILE=$TEMP/${BN%.sh}.~$$~

# set existing environment

. functions.sh
ETC_DEFAULT=$(readlink -f "$ETC_DEFAULT")
[[ -f "$ETC_DEFAULT" ]] && . "$ETC_DEFAULT"
cp -p "$DEFAULT_EPT" "$TEMP_FILE" || exit 1
touch "$TEMP_FILE".value || exit 1
set | awk -F= '{print $1}' > "$TEMP_FILE".set

# foreach ENVVAR in $DEFAULT_EPT set value in $TEMP_FILE
awk -F= '/^\s*\w.*=/{print $1}' "$DEFAULT_EPT" | while read ENVVAR ; do
  ENVVAR_KEY=$ENVVAR
  if [[ $ENVVAR = EPAGES_HTTPD_ROOT && -f "$HTTPD_ROOT"/bin/httpd.sh ]] ; then
    grep -q "^$ENVVAR$" "$TEMP_FILE".set || {
      grep -q "^HTTPD_ROOT$" "$TEMP_FILE".set && ENVVAR=HTTPD_ROOT
    }
  fi
  grep -q "^$ENVVAR$" "$TEMP_FILE".set || continue # new variable
  [[ $ENVVAR = JAVA_HOME ]] && continue # treat JAVA_HOME specially

  ENV=$(ini-config.sh -f "$ETC_DEFAULT" -k $ENVVAR -G)

  # treat ENVVAR=$(...) specially
  if [[ $ENV != ${ENV#\$(} ]] ; then
    ini-config.sh -f "$TEMP_FILE" -k $ENVVAR_KEY -v "\"$ENV\"" -i
    continue
  fi

  # find old ENVVAR value
  ENV=$(eval echo '$'$ENVVAR)

  # make ENVVAR shorter (/srv/epages/eproot/a -> $EPAGES/a etc.)
  unset SHORTER key value
  if [[ ${ENV#*/} != $ENV ]] ; then # ENV has slash
    while read key value ; do
      [[ ${ENV#$value} != $ENV ]] && SHORTER="$key ${ENV#$value}"
    done < "$TEMP_FILE".value
    echo "$ENVVAR $ENV" >> "$TEMP_FILE".value
  fi
  [[ -n $SHORTER ]] && ENV="\$${SHORTER%% *}${SHORTER#* }"

  # quote ENVVAR unless is number
  [[ -n ${ENV//[0-9]/} ]] && ENV="\"$ENV\""

  ini-config.sh -f "$TEMP_FILE" -k $ENVVAR_KEY -v "$ENV" -i
done

[[ -z $INPLACE ]] && cat "$TEMP_FILE" || cat "$TEMP_FILE" > "$ETC_DEFAULT"

rm -f "$TEMP_FILE"*

exit 0
