#!/bin/bash

#=======================================================================
# preinstall/epages.sh creates Shared/Config/epages.conf
#=======================================================================

if [ ! -w /etc/passwd ] ; then
  echo "$0: only 'root' can execute this program"
  exit 1
fi

#-----------------------------------------------------------------------
# ECHO
#-----------------------------------------------------------------------

ECHO () {
  local LINE_NUMBER=$(printf "%3d" $1)
  shift
  [[ -n $EPAGES_INSTALLATION_MOCK ]] && echo "$@" || echo -e "[${0##*/}:$LINE_NUMBER] $@"
}

#-----------------------------------------------------------------------
# define variables and functions
#-----------------------------------------------------------------------

[[ -n $1 ]] || exit 0

EPAGES_INSTALL_CONF=$(readlink -m $1)
EPAGES_CONFIG_ENV=$EPAGES_CONFIG

FUN_DIR=$(cd $(dirname $0)/../functions && pwd)

. $FUN_DIR/fun-epages.sh
export fun_epages_sourced
export -f find_ini_config get_ini_value set_ini_value etc_default

. $FUN_DIR/fun-host.sh
export fun_host_sourced
export -f get_name_by_ip

. $FUN_DIR/fun-configure.sh
export fun_configure_sourced
export -f get_install_host

. $FUN_DIR/fun-arch.sh
export fun_arch_sourced
export -f absolute_path

. $(etc_default)

INI_CONFIG=$(find_ini_config) || exit 1

EPAGES=${EPAGES:-/srv/epages/eproot}
EPAGES_CONFIG=${EPAGES_CONFIG:-$EPAGES/Shared/Config}
EPAGES_CONFIG=${EPAGES_CONFIG_ENV:-$EPAGES_CONFIG}

#-----------------------------------------------------------------------
# update Shared/Config/epages.conf
#-----------------------------------------------------------------------

ls $EPAGES_CONFIG/epages.conf >/dev/null || exit 0

EPAGES_CONF_NEW=$(get_ini_value "$EPAGES_INSTALL_CONF" epages-conf 'general definitions') || true
EPAGES_CONF_NEW=$(absolute_path "$EPAGES_CONF_NEW" "$EPAGES_INSTALL_CONF") || true

set -e

unset DN
if [[ -f "$EPAGES_CONF_NEW" ]] ; then
  for section in $($INI_CONFIG -f "$EPAGES_CONF_NEW" -G) ; do
    $INI_CONFIG -f "$EPAGES_CONF_NEW" -s "$section" -G \
      | while IFS== read key value ; do
      ECHO $LINENO "set_ini_value --overwrite $EPAGES_CONFIG/epages.conf $key $value $section"
      set_ini_value --overwrite $EPAGES_CONFIG/epages.conf "$key" "$value" "$section"
    done
  done
  DN=$(get_ini_value "$EPAGES_CONF_NEW" SystemDomainName DE_EPAGES::Object) || true
fi

[[ -z $DN ]] || exit 0
[[ -f $EPAGES_INSTALL_CONF ]] || exit 0

if [[ -f  /etc/sysconfig/epages6 ]] ; then
  . /etc/sysconfig/epages6
  DN=$EPAGES_INSTALL_WS_HOST
fi

if [[ -z $DN ]] ; then
  unset USED_WEBCONF WEBCONF
  while read section ; do
    VALUE=$(get_ini_value "$EPAGES_INSTALL_CONF" webconf "$section") || continue
    if [[ ${VALUE:-0} != 0 ]] ; then
      WEBCONF=$section
      [[ $VALUE =~ standby ]] || { USED_WEBCONF=$section; break; }
    fi
  done < <($INI_CONFIG -f $EPAGES_INSTALL_CONF -G)

  # use standby web server if no other found
  USED_WEBCONF=${USED_WEBCONF:-$WEBCONF}
  [[ -n $USED_WEBCONF ]] || exit 0

  DN=$(get_install_host $EPAGES_INSTALL_CONF $USED_WEBCONF)
  # translate IP
  if [[ $DN =~ : || -z ${DN//[0-9.]/} ]] ; then
    # into full name
    DN=$(get_name_by_ip $DN | tr ' ' '\n' | grep '\.' | head -1)
    # or short name
    DN=${DN:-$(get_name_by_ip $DN | sed 's, .*,,')}
  fi
fi

[[ -n $DN ]] || exit 0

ECHO $LINENO "set_ini_value --overwrite $EPAGES_CONFIG/epages.conf SystemDomainName $DN DE_EPAGES::Object"
set_ini_value --overwrite $EPAGES_CONFIG/epages.conf SystemDomainName $DN DE_EPAGES::Object

exit 0
