#!/bin/bash

#=======================================================================
#  preinstall/mysqld.sh creates configuration files in Database.d
#=======================================================================

if [ ! -w /etc/passwd ] ; then
  echo "$0: only 'root' can execute this program"
  exit 1
fi

#-----------------------------------------------------------------------
# ECHO
#-----------------------------------------------------------------------

ECHO () {
  local LINE_NUMBER=$(printf "%3d" $1)
  shift
  [[ -n $EPAGES_INSTALLATION_MOCK ]] && echo "$@" || echo -e "[${0##*/}:$LINE_NUMBER] $@"
}

#-----------------------------------------------------------------------
# define variables and functions
#-----------------------------------------------------------------------

[[ -n $1 ]] && EPAGES_INSTALL_CONF=$(readlink -m $1) || EPAGES_INSTALL_CONF=

EPAGES_CONFIG_ENV=$EPAGES_CONFIG
FUN_DIR=$(cd $(dirname $0)/../functions && pwd)

. $FUN_DIR/fun-epages.sh
export fun_epages_sourced
export -f etc_default find_ini_config get_ini_value
. $FUN_DIR/fun-arch.sh
export fun_arch_sourced
export -f absolute_path
. $FUN_DIR/fun-configure.sh
export fun_configure_sourced
export -f get_install_host
. $FUN_DIR/install-mysqld.sh
export install_mysqld_sourced
export -f update_database_conf
. $FUN_DIR/fun-host.sh
export fun_host_sourced
export -f my_ips

. $(etc_default)

INI_CONFIG=$(find_ini_config) || exit 1

EPAGES_CONFIG=${EPAGES_CONFIG:-/srv/epages/eproot/Shared/Config}
EPAGES_CONFIG=${EPAGES_CONFIG_ENV:-$EPAGES_CONFIG}

#-----------------------------------------------------------------------
# general_definition
#-----------------------------------------------------------------------

unset INSTALL_EPAGES_MYSQL_PASS INSTALL_EPAGES_MY_CNF

general_definition () {
  local CONFIGFILE=$1
  local KEY=$2
  local VALUE
  VALUE=$(get_ini_value "$CONFIGFILE" "$KEY" 'general definitions') || return 1

  case $KEY in
    mysqld-root-password)
      export INSTALL_EPAGES_MYSQL_PASS="$VALUE"
      ECHO $LINENO "$CONFIGFILE: INSTALL_EPAGES_MYSQL_PASS=$VALUE" ;;
    my-cnf)
      export INSTALL_EPAGES_MY_CNF="$VALUE"
      ECHO $LINENO "$CONFIGFILE: INSTALL_EPAGES_MY_CNF=$VALUE" ;;
  esac
  return 0
}

#------------------------------------------------------------------------------
# create Database.d/*.conf
#------------------------------------------------------------------------------

set -e

USE_DEFAULT=
USED_DATABASES=
export INSTALL_EPAGES_HOST=

if [[ -f $EPAGES_INSTALL_CONF ]] ; then
  while read section ; do
    # ignore sections with spaces in name
    [[ ! $section =~ ' ' ]] || continue
    # ignore sections without mysqld= key
    MYSQLD_INSTALL_CONF=$(get_ini_value "$EPAGES_INSTALL_CONF" mysqld "$section") || continue
    # ignore sections with mysqld= key is empty/0/standby
    [[ ${MYSQLD_INSTALL_CONF:-0} = 0 || $MYSQLD_INSTALL_CONF =~ standby ]] && continue || true
    # use default databases if $MYSQLD_INSTALL_CONF does not exist
    if ! MYSQLD_INSTALL_CONF=$(absolute_path "$MYSQLD_INSTALL_CONF" $EPAGES_INSTALL_CONF)
    then
      USE_DEFAULT=$section
      continue
    fi

    general_definition "$MYSQLD_INSTALL_CONF" mysqld-root-password \
      || general_definition "$EPAGES_INSTALL_CONF" mysqld-root-password \
      || unset INSTALL_EPAGES_MYSQL_PASS

    general_definition "$MYSQLD_INSTALL_CONF" my-cnf \
      || general_definition "$EPAGES_INSTALL_CONF" my-cnf \
      || unset INSTALL_EPAGES_MY_CNF

    INSTALL_EPAGES_HOST=$(get_install_host $EPAGES_INSTALL_CONF $section)
    for database in $($INI_CONFIG -f $MYSQLD_INSTALL_CONF -G | grep -v ' ') ; do
      # define datasource host
      USED_DATABASES="$USED_DATABASES $database"
      ECHO $LINENO "update_database_conf $database $MYSQLD_INSTALL_CONF"
      update_database_conf $database $MYSQLD_INSTALL_CONF || false
    done
  done < <($INI_CONFIG -f $EPAGES_INSTALL_CONF -G)

else
  USE_DEFAULT=1
fi

if [[ -n $USE_DEFAULT ]] ; then
  if [[ -f $EPAGES_INSTALL_CONF ]] ; then
    INSTALL_EPAGES_HOST=$(get_install_host "$EPAGES_INSTALL_CONF" $USE_DEFAULT)
  fi
  INSTALL_EPAGES_HOST=${INSTALL_EPAGES_HOST:-$INSTALL_EPAGES_MYSQL_HOST}
  INSTALL_EPAGES_HOST=${INSTALL_EPAGES_HOST:-$(my_ips | grep '\.' | head -1)}
  ECHO $LINENO "INSTALL_EPAGES_HOST=$INSTALL_EPAGES_HOST"
  for default_database in Site Store System ASPoolDB epagesj ; do
    echo $USED_DATABASES | grep -q "\b$default_database\b" || {
      ECHO $LINENO "update_database_conf $default_database"
      update_database_conf $default_database
    }
  done
fi

set +e
ECHO $LINENO "/etc/init.d/epages6 perm admin"
/etc/init.d/epages6 perm admin >/dev/null 2>&1 

exit 0
