#!/bin/bash

##############################################################################
# this script runs tests with shunit2 methods                                #
##############################################################################

# install if shunit2 not found
PATH=$PATH:/usr/share/shunit2
if ! type shunit2 >/dev/null 2>&1 && [[ -f /etc/debian_version ]] ; then
  apt-get install shunit2
elif ! type shunit2 >/dev/null 2>&1 && [[ -f /etc/redhat-release ]] ; then
  rpm -hiv http://download.fedoraproject.org/pub/epel/6/i386/shunit2-2.1.6-3.el6.noarch.rpm
fi

# die if shunit2 not found
SHUNIT2=$(type -p shunit2) || exit 1

# test script directory: /var/epages/t
TEST_DIR=$(cd $(dirname $0) && pwd)
TEST_FILE=$(basename $0)

# script to test: /var/epages/functions/${TEST_FILE%-test.sh}.sh
SCRIPT_TO_TEST=${TEST_DIR%/*}/functions/${TEST_FILE%-test.sh}.sh

. $SCRIPT_TO_TEST

echo -e "testing: $0\nscript to test: $SCRIPT_TO_TEST\n"

##############################################################################
# re-define functions                                                        #
##############################################################################

function setUp() {
  DIR=/tmp/pid.~$$~/1/2
  rm -rf /tmp/pid.~$$~
  mkdir -m 755 -p $DIR
  touch $DIR/file
}

function TearDown() {
  rm -rf /tmp/pid.~$$~
}

##############################################################################
# test functions                                                             #
##############################################################################

function test_absolute_path() {
  local FOUND EXPECTED

  absolute_path --help 2>&1 | grep -q 'syntax: absolute_path'
  assertTrue "[FAILED] absolute_path --help" $?

  absolute_path
  assertFalse "[FAILED] absolute_path -> false" $?

  FOUND=$(absolute_path /kwats/foo/../bar/bang)
  assertFalse "[FAILED] absolute_path /kwats/foo/../bar/bang -> false" $?
  EXPECTED="/kwats/bar/bang"
  assertEquals "[FAILED] absolute_path /kwats/foo/../bar/bang" "$EXPECTED" "$FOUND"

  FOUND=$(absolute_path kwats)
  assertFalse "[FAILED] absolute_path kwats -> false" $?
  EXPECTED="$(pwd)/kwats"
  assertEquals "[FAILED] absolute_path kwats" "$EXPECTED" "$FOUND"

  FOUND=$(absolute_path $(dirname $DIR)/../2)
  assertTrue "[FAILED] absolute_path $(dirname $DIR)/../2 -> true" $?
  EXPECTED="$(dirname ${DIR%/*})/2"
  assertEquals "[FAILED] absolute_path $(dirname $DIR)/../2" "$EXPECTED" "$FOUND"

  FOUND=$(absolute_path file $DIR/base)
  assertTrue "[FAILED] absolute_path file $DIR/base -> true" $?
  EXPECTED="$DIR/file"
  assertEquals "[FAILED] absolute_path file $DIR/base" "$EXPECTED" "$FOUND"

  FOUND=$(absolute_path otherfile $DIR/base)
  assertFalse "[FAILED] absolute_path file $DIR/base -> false" $?
  EXPECTED="$DIR/otherfile"
  assertEquals "[FAILED] absolute_path file $DIR/base" "$EXPECTED" "$FOUND"

  FOUND=$(absolute_path otherfile/x $DIR/base)
  assertFalse "[FAILED] absolute_path file otherfile/x $DIR/base -> false" $?
  EXPECTED="$DIR/otherfile/x"
  assertEquals "[FAILED] absolute_path otherfile/x $DIR/base" "$EXPECTED" "$FOUND"

  FOUND=$(absolute_path . $DIR/base)
  assertTrue "[FAILED] absolute_path file . $DIR/base -> true" $?
  EXPECTED="$DIR"
  assertEquals "[FAILED] absolute_path . $DIR/base" "$EXPECTED" "$FOUND"
}

##############################################################################
# source shunit2                                                             #
##############################################################################

. $SHUNIT2
