#!/srv/epages/eproot/Perl/bin/perl
use strict;
use Test::More tests => 2;
use Config::IniFiles;
use File::Basename  qw ( dirname );
use Data::Dumper;

use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::File qw( AbsolutePath RealPath );

our ($EXPECTED, %FOUND);
our $TestDir = dirname(RealPath(AbsolutePath($0)));
our $ConfigDir = dirname($TestDir). '/conf/mysqld';

sub Main {
    foreach my $ConfigType (qw(complex simple)) {
        my $ConfigFile = "$ConfigDir/$ConfigType.conf";
        tie %FOUND, 'Config::IniFiles', ( -file => $ConfigFile ) or die $!;
        print Dumper(\%FOUND) if $ENV{DUMP_CONFIG};
        is_deeply( \%FOUND, $EXPECTED->{$ConfigType}, "conf -> hash: $ConfigType.conf" );
    }
}

$EXPECTED = {
    'complex' => {
        'Site' => {
            'StoreType' => 'Site',
            'Key' => '1234567890abcdef',
            'Backup' => 'Backup',
            'StoreType.Add' => 'DE_EPAGES::Diagnostics',
            'StoreType.Lang' => 'en-US ca cs da de es fi fr it nl no ru sv pt-BR',
        },
        'Store' => {
            'StoreType' => 'Store',
            'Key' => '1234567890abcdef',
            'Backup' => 'Backup',
            'StoreType.Add' => 'DE_EPAGES::Diagnostics DE_EPAGES::ELogistics DE_EPAGES::Envialia DE_EPAGES::TagCommander',
            'StoreType.Lang' => 'en ca cs da de es fi fr it nl no pt ru sv',
        },
        'StoreenUS' => {
            'StoreType' => 'StoreenUS',
            'Backup' => 'Backup',
            'StoreType.Base' => 'Store',
            'StoreType.Lang' => 'en-US',
        },
        'StoreptBR' => {
            'StoreType' => 'StoreptBR',
            'Backup' => 'Backup',
            'StoreType.Base' => 'Store',
            'StoreType.Lang' => 'pt-BR',
        },
        'System' => {
            'StoreType' => 'System',
            'Backup' => 'Backup',
        },
        'Monitor' => {
            'StoreType' => 'Monitor',
            'Backup' => 'Backup',
            'StoreType.Base' => 'Common',
            'StoreType.Add' => 'DE_EPAGES::Calendar DE_EPAGES::Address DE_EPAGES::Shop DE_EPAGES::MediaGallery DE_EPAGES::Design DE_EPAGES::ShopMailType DE_EPAGES::ShopCSVExportImport DE_EPAGES::Content DE_EPAGES::ShopWizard DE_EPAGES::SEO DE_EPAGES::Forum DE_EPAGES::Tax DE_EPAGES::Customer DE_EPAGES::Shipping DE_EPAGES::Payment DE_EPAGES::Order DE_EPAGES::ShippingOption DE_EPAGES::Product DE_EPAGES::Catalog DE_EPAGES::ProductRating DE_EPAGES::ShoppingList DE_EPAGES::ProductComparison DE_EPAGES::RemoteSearch DE_EPAGES::ShippingTypes DE_EPAGES::PaymentTypes DE_EPAGES::CustomForm',
        },
        'Backup' => {
            'Database' => 'mysql',
            'login' => 'root',
        },
        'ASPoolDB' => {
            'StoreType' => 'ASPoolDB',
            'Database' => 'aspooldb',
            'Backup' => 'Backup',
        },
        'epagesj' => {
            'Database' => 'epagesj',
            'Backup' => 'Backup',
        },
        'PatchSystemInfoDB' => {
            'Database' => 'patchsysteminfodb',
            'login' => 'usr_patch',
            'Backup' => 'Backup',
        }
    }, 'simple' => {
        'general definitions' => {
            'my-cnf' => '',
        },
        'Site' => {
            'StoreType' => 'Site',
            'Database' => 'sitedb',
            'login' => 'usr_sitedb',
            'passwd' => 'epages',
            'Backup' => 'Backup',
            'BackupHost' => 'localhost',
        },
        'Store' => {
            'StoreType' => 'Store',
            'Backup' => 'Backup',
        },
        'System' => {
            'StoreType' => 'System',
            'Backup' => 'Backup',
        },
        'Backup' => {
            'Database' => 'mysql',
            'login' => 'root',
        },
        'ASPoolDB' => {
            'StoreType' => 'ASPoolDB',
            'Database' => 'aspooldb',
            'Backup' => 'Backup',
        },
        'epagesj' => {
            'Database' => 'epagesj',
            'Backup' => 'Backup',
        },
        'PatchSystemInfoDB' => {
            'Database' => 'patchsysteminfodb',
            'login' => 'usr_patch',
            'Backup' => 'Backup',
        },
    },
};

RunScript( Sub => \&Main, Debug => 1, Message => 'long' );

1;
