#!/bin/bash

##############################################################################
# this script runs tests with shunit2 methods
##############################################################################

# die if shunit2 not found
type shunit2 && SHUNIT2=$(type -p shunit2) || exit 1

# test script directory (/var/epages/t)
TEST_DIR=$(cd $(dirname $0) && pwd)
TEST_FILE=$(basename $0)
TEST_FILE=${TEST_FILE#post-}

# script to test
SCRIPT_TO_TEST=${TEST_DIR%/*}/postinstall/${TEST_FILE%-test.sh}.sh

. ${TEST_DIR%/*}/functions/fun-epages.sh
export get_ini_value set_ini_value

echo -e "testing: $0\nscript to test: $SCRIPT_TO_TEST\n"

##############################################################################
# re-define functions                                                        #
##############################################################################

function oneTimeSetUp() {
  echo '-> export EPAGES_INSTALLATION_MOCK=1'
  TEMP=/tmp/${0##*/}.~$$~
  TEST_CONFD=$TEMP/eproot/Shared/Config
  INSTALL_EPAGES_CONF=$TEMP/conf/install-epages.conf.sample
  TEST_OUTPUT=$TEMP/test.output
  rm -rf $TEMP/*
  mkdir -m 755 -p ${TEST_CONFD%/*}
  cp -rp ${TEST_DIR%/*}/conf $TEMP
}

function oneTimeTearDown() {
  if [[ -n $KEEP_TEST_CONF ]] ; then
    echo "test_configdir: $TEMP"
  else
    rm -rf $TEMP
  fi
}

##############################################################################
# define functions                                                           #
##############################################################################

#-----------------------------------------------------------------------------
# test functions
#-----------------------------------------------------------------------------

function test_script_syntax() {
  # script must have correct syntax
  bash -n $SCRIPT_TO_TEST
  assertTrue "[FAILED] bash -n $SCRIPT_TO_TEST" $? || exit 1
}

function test_script_executable() {
  # script must be executable
  test -x $SCRIPT_TO_TEST
  assertTrue "[FAILED] test -x $SCRIPT_TO_TEST" $?
  chmod 755 $SCRIPT_TO_TEST
}

function test_secret_key_unset() {
  export EPAGES_INSTALLATION_MOCK=1

  J_CONFIGFILE=$TEMP/conf/j/localhost.conf
  echo "-> secret.key= $SCRIPT_TO_TEST $J_CONFIGFILE"

  $SCRIPT_TO_TEST $J_CONFIGFILE | grep -q "application-secret-key.conf secret.key"
  assertFalse "[FAILED] secret.key= $SCRIPT_TO_TEST $J_CONFIGFILE" $?
}

function test_secret_key_set() {
  export EPAGES_INSTALLATION_MOCK=1

  J_CONFIGFILE=$TEMP/conf/j/localhost.conf
  set_ini_value --overwrite $J_CONFIGFILE secret.key 123 application-secret-key
  echo "-> secret.key=123 $SCRIPT_TO_TEST $J_CONFIGFILE"

  $SCRIPT_TO_TEST $J_CONFIGFILE | grep -q "application-secret-key.conf secret.key '123'"
  assertTrue "[FAILED] secret.key=123 $SCRIPT_TO_TEST $J_CONFIGFILE" $?
  echo
}

function test_standby() {
  export EPAGES_INSTALLATION_MOCK=1

  echo "-> export EPAGES_INSTALLATION_MOCK=$EPAGES_INSTALLATION_MOCK"
  echo "-> $SCRIPT_TO_TEST /tmp/standby"
  $SCRIPT_TO_TEST /tmp/standby | tee $TEST_OUTPUT
  grep -q 'EPAGES_SPEC_SKIP_RESTART=1 (/standby in /tmp/standby)' $TEST_OUTPUT
  assertTrue "[FAILED] grep -q 'EPAGES_SPEC_SKIP_RESTART=1 (/standby in /tmp/standby)'" $?
}

##############################################################################
# source shunit2                                                             #
##############################################################################

. $SHUNIT2
