#!/bin/bash

##############################################################################
# this script runs tests with shunit2 methods
##############################################################################

# die if shunit2 not found
type shunit2 && SHUNIT2=$(type -p shunit2) || exit 1

# test script directory (/var/epages/t)
TEST_DIR=$(cd $(dirname $0) && pwd)
TEST_FILE=$(basename $0)
TEST_FILE=${TEST_FILE#post-}

# script to test
SCRIPT_TO_TEST=${TEST_DIR%/*}/postinstall/${TEST_FILE%-test.sh}.sh

. ${TEST_DIR%/*}/functions/fun-epages.sh
export get_ini_value set_ini_value

echo -e "testing: $0\nscript to test: $SCRIPT_TO_TEST\n"

##############################################################################
# re-define functions                                                        #
##############################################################################

function oneTimeSetUp() {
  echo '-> export EPAGES_INSTALLATION_MOCK=1'
  TEMP=/tmp/${0##*/}.~$$~
  TEST_CONFD=$TEMP/eproot/Shared/Config
  INSTALL_EPAGES_CONF=$TEMP/conf/install-epages.conf.sample
  TEST_OUTPUT=$TEMP/test.output
  rm -rf $TEMP/*
  mkdir -m 755 -p ${TEST_CONFD%/*} $TEMP/eproot/Perl/bin $TEMP/etc/default
  cp -rp ${TEST_DIR%/*}/conf $TEMP

  # use Perl/bin/perl with changed EPAGES_CONFIG
  cp -p /srv/epages/eproot/Perl/bin/perl $TEMP/eproot/Perl/bin || exit 1
  /var/epages/ini-config.sh -f /etc/default/epages6 -k EPAGES_CONFIG -v $TEST_CONFD > $TEMP/etc/default/epages6
  /var/epages/ini-config.sh -f $TEMP/etc/default/epages6 -k PERL -v $TEMP/eproot/Perl/bin/perl -i
  chmod 644 $TEMP/etc/default/epages6
  cp -rp /srv/epages/eproot/Shared/Config $TEST_CONFD || exit 1
  rm -rf $TEST_CONFD/Database.d/* || exit 1
}

function oneTimeTearDown() {
  if [[ -n $KEEP_TEST_CONF ]] ; then
    echo "test_configdir: $TEMP"
  else
    rm -rf $TEMP
  fi
}

##############################################################################
# define functions                                                           #
##############################################################################

#-----------------------------------------------------------------------------
# test functions
#-----------------------------------------------------------------------------

function test_script_syntax() {
  # script must have correct syntax
  bash -n $SCRIPT_TO_TEST
  assertTrue "[FAILED] bash -n $SCRIPT_TO_TEST" $? || exit 1
}

function test_script_executable() {
  # script must be executable
  test -x $SCRIPT_TO_TEST
  assertTrue "[FAILED] test -x $SCRIPT_TO_TEST" $?
  chmod 755 $SCRIPT_TO_TEST
  echo
}

function test_basic() {
  export EPAGES_INSTALLATION_MOCK=1
  export EPAGES_CONFIG=$TEST_CONFD
  export PERL=$TEMP/eproot/Perl/bin/perl 
  export EPAGES_MYSQL_ROOT_SCRIPT=postinstall/mysqld.sh

  MYSQLD_CONFIGFILE=
  echo "-> $SCRIPT_TO_TEST $MYSQLD_CONFIGFILE"

  # shunit2 traps the TERM signal we want to ignore
  trap '' TERM
  $SCRIPT_TO_TEST $MYSQLD_CONFIGFILE | tee $TEST_OUTPUT
  for BU in Site Store System ASPoolDB epagesj ; do
    grep -q "createDB.pl -storename $BU" $TEST_OUTPUT
    assertTrue "[FAILED] createDB.pl -storename $BU" $?
  done
  echo
}

function test_standby() {
  export EPAGES_INSTALLATION_MOCK=1
  export EPAGES_MYSQL_ROOT_SCRIPT=postinstall/mysqld.sh

  echo "-> export EPAGES_INSTALLATION_MOCK=$EPAGES_INSTALLATION_MOCK"
  echo "-> $SCRIPT_TO_TEST /tmp/standby"
  $SCRIPT_TO_TEST /tmp/standby | tee $TEST_OUTPUT
  grep -q 'EPAGES_SPEC_SKIP_RESTART=1 (/standby in /tmp/standby)' $TEST_OUTPUT
  assertTrue "[FAILED] grep -q 'EPAGES_SPEC_SKIP_RESTART=1 (/standby in /tmp/standby)'" $?
}

##############################################################################
# source shunit2                                                             #
##############################################################################

. $SHUNIT2
